driveCmd

package
v0.0.0-...-9bcff37 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2026 License: MIT Imports: 19 Imported by: 0

Documentation

Overview

Package driveCmd implements the drive subcommands for proton-cli.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddCommand

func AddCommand(cmd *cobra.Command)

AddCommand registers a subcommand under the drive command group.

func ResolveProtonPath

func ResolveProtonPath(ctx context.Context, dc *drive.Client, rawPath string) (*drive.Link, *drive.Share, error)

ResolveProtonPath parses a proton:// URI and resolves it to a Link and Share.

Types

type PathType

type PathType int

PathType distinguishes local filesystem paths from Proton Drive paths.

const (
	// PathLocal is a local filesystem path.
	PathLocal PathType = iota
	// PathProton is a Proton Drive path (proton:// URI).
	PathProton
)

Directories

Path Synopsis
Package shareCmd implements the share subcommands for proton-cli.
Package shareCmd implements the share subcommands for proton-cli.

Jump to